###############################################################################################################################
###############################################################################################################################
###############################################################################################################################

        # Python script for Figures in following paper (c) by W. Yao, L. Puts, K. Williams and D. Lenstra
        # as part of the work published in "An All-Optical Spiking Laser Neuron Integrated in Generic 
        # InP Photonic Circuit Technology" published in Optics Express
        # 
        # This work is licensed under a Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License.
        # 
        # You should have received a copy of the license along with this work. If not, see 
        # <https://creativecommons.org/licenses/by-nc-sa/4.0/>.
        
        # Eindhoven Univesity of Technology, Eindhoven, the Netherlands, May 2025
        
        # Contact: l.puts@tue.nl

###############################################################################################################################
###############################################################################################################################
###############################################################################################################################

import numpy as np
import matplotlib.pyplot as plt

plt.rcParams["font.family"] = 'Times New Roman'
plt.rcParams['font.size'] = 14
plt.rcParams['mathtext.default'] = 'regular'


att=[0,1,2,3]


for i in range(len(att)):
   
    
    file='Timing injection at BPF 1547 nm VOA '+str('{0:.4f}'.format(att[i]))+' dB.npy'
    data=np.load(file)
    
    time=data[0,:]*1e9
    signal_inj=data[1,:]
    signal_res=data[3,:]

    fig, ax = plt.subplots(1,2,figsize=(8, 1.5))
    fig.patch.set_alpha(0)
    ax[0].plot(time, signal_inj,color='k',linewidth=0.5)
    ax[1].plot(time-4.8, signal_res,color='k',linewidth=0.5)
    ax[0].set_ylim([-0.0010,0.007])
    ax[1].set_ylim([-0.01,0.11])
    ax[1].set_xlim([0,200])
    ax[0].set_xlim([0,200])
    ax[0].set_xlabel(' ', fontsize=10)
    ax[1].set_xlabel(' ', fontsize=10)
    ax[0].set_xlabel('Time [ns]', fontsize=10)
    ax[1].set_xlabel('Time [ns]', fontsize=10)
    ax[0].set_ylabel('Inj. signal [V]', fontsize=10)
    ax[1].set_ylabel('Exc. signal [V]', fontsize=10)
    plt.tight_layout()
